@@ -5,11 +5,33 @@ use warnings;
 
 use IUP::Internal::LibraryIup;
 use IUP::Internal::Callback;
-use IUP::Internal::Attribute;
 use IUP::Constants qw(IUP_CURRENT);
 use Carp;
 use Scalar::Util qw(blessed looks_like_number);
 
+sub import {
+  my $p = shift;
+  #warn "### IUP::Internal::Element->import($p) called";
+
+  # callback accessors
+  if (my $c = IUP::Internal::Callback::_get_cb_eval_code($p)) {
+    eval($c);
+    die "###ERROR### import failed(cb) '$p': " . $@ if $@;
+  }
+}
+
+sub AUTOLOAD {
+  my ($name) = our $AUTOLOAD =~ /::(\w+)$/;
+  die "FATAL: unknown method '$name'" unless $name =~ /^[A-Z0-9_]+$/;
+  my $method = sub {
+        return $_[0]->GetAttribute($name) if scalar(@_) == 1; 
+        return $_[0]->SetAttribute($name, $_[1]) if scalar(@_) > 1;
+  };
+  no strict 'refs';
+  *{$AUTOLOAD} = $method;
+  goto &$method;
+}
+
 sub BEGIN {
   #warn "***DEBUG*** IUP::Internal::Element::BEGIN() started\n";
   IUP::Internal::LibraryIup::_IupControlsOpen();
@@ -97,24 +119,6 @@ sub ihandle {
   }
 }
 
-sub import {
-  my $p = shift;
-  #warn "### IUP::Internal::Element->import($p) called";
-
-  # callback accessors
-  if (my $c = IUP::Internal::Callback::_get_cb_eval_code($p)) {
-    eval($c);
-    die "###ERROR### import failed(cb) '$p': " . $@ if $@;
-  }
-  
-  # attribute accessors
-  if (my $a = IUP::Internal::Attribute::_get_attr_eval_code($p)) {
-    eval($a);
-    die "###ERROR### import failed(attr) '$p': " . $@ if $@;
-  }
-  
-}
-
 sub GetName {
   #char* IupGetName(Ihandle* ih); [in C]
   #iup.GetName(ih: ihandle) -> (name: string) [in Lua]
@@ -674,7 +678,7 @@ sub _proc_child_param_single {
 
 1;
 
-__END__
+=pod
 
 =head1 NAME
 
